#ifndef NT2_INCLUDE_FUNCTIONS_MULS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MULS_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/muls.hpp>

#endif
